"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = __importDefault(require("flex-dev-utils/dist/axios"));
var querystring_1 = require("querystring");
var util_1 = require("util");
var flex_dev_utils_1 = require("flex-dev-utils");
var Http = /** @class */ (function () {
    function Http(config) {
        var _this = this;
        /**
         * Uploads the {@link FormData} to the URL
         *
         * @param url       the url to upload to
         * @param formData  the {@link FormData}
         */
        this.upload = function (url, formData) {
            flex_dev_utils_1.logger.debug('Uploading formData to %s', url);
            flex_dev_utils_1.logger.trace(formData);
            return axios_1.default
                .post(url, formData, {
                headers: formData.getHeaders(),
                auth: {
                    username: _this.config.auth.username,
                    password: _this.config.auth.password,
                },
            })
                .then(function (resp) { return resp.data; })
                .catch(_this.onError);
        };
        /**
         * Private error handler
         * @param err Axios error
         */
        this.onError = function (err) {
            flex_dev_utils_1.logger.trace('Http request failed', err);
            var request = err.config || {};
            var resp = err.response || {};
            var status = resp.status;
            var msg = resp.data && resp.data.message || resp.data;
            var title = 'Request %s to %s failed with status %s and message %s';
            var errMsg = util_1.format(title, request.method, request.url, status, msg);
            if (_this.config.exitOnRejection) {
                throw new Error(errMsg);
            }
            else {
                return Promise.reject(err);
            }
        };
        this.config = config;
        this.jsonPOST = config.contentType === 'application/json';
        this.client = axios_1.default.create({
            baseURL: config.baseURL,
            auth: {
                username: config.auth.username,
                password: config.auth.password,
            },
            headers: {
                'Content-Type': config.contentType ? config.contentType : 'application/x-www-form-urlencoded',
            },
        });
        if (config.userAgent) {
            this.client.defaults.headers['User-Agent'] = config.userAgent;
        }
        this.client.interceptors.response.use(function (r) { return r; }, this.onError);
    }
    /**
     * List API endpoint; makes a GET request and returns an array of R
     * @param uri   the uri endpoint
     */
    Http.prototype.list = function (uri) {
        return this.get(uri);
    };
    /**
     * Makes a GET request to return an instance
     * @param uri   the uri endpoint
     */
    Http.prototype.get = function (uri) {
        flex_dev_utils_1.logger.debug('Making GET request to %s/%s', this.config.baseURL, uri);
        return this.client
            .get(uri)
            .then(function (resp) { return resp.data || {}; });
    };
    /**
     * Makes a POST request
     * @param uri   the uri of the endpoint
     * @param data  the data to post
     */
    Http.prototype.post = function (uri, data) {
        flex_dev_utils_1.logger.debug('Making POST request to %s/%s with data %s', this.config.baseURL, uri, JSON.stringify(data));
        if (!this.jsonPOST) {
            data = querystring_1.stringify(data);
        }
        return this.client
            .post(uri, data)
            .then(function (resp) { return resp.data; });
    };
    /**
     * Makes a delete request
     *
     * @param uri   the uri of the endpoint
     */
    Http.prototype.delete = function (uri) {
        flex_dev_utils_1.logger.debug('Making DELETE request to %s/%s', this.config.baseURL, uri);
        return this.client
            .delete(uri);
    };
    /**
     * Determines the content type based on file extension
     *
     * @param filePath  the local path to the file
     * @returns the content type
     */
    Http.getContentType = function (filePath) {
        var ext = filePath.split('.').pop();
        if (ext === 'js') {
            return 'application/javascript';
        }
        else if (ext === 'map') {
            return 'application/json';
        }
        return 'application/octet-stream';
    };
    return Http;
}());
exports.default = Http;
//# sourceMappingURL=http.js.map